use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006000
eval "use Test::Spelling 0.12; use Pod::Wordlist::hanekomu; 1" or die $@;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Alessandro
CA's
CAcert
Claes
EINTR
Eklund
Ghedini
IPv
Jakobsson
Lukas
Nehren
SSL
Serguei
Trouchelle
Weyl
Zborowski
chunked
iteratively
proxied
redirections
timestamp
Christian
Hansen
chansen
David
Golden
dagolden
Alan
Gardner
gardner
al3xbio
Brad
Gilbert
bgills
Chris
apeiron
cweyl
claes
Craig
Berry
cberry
Mitchell
davem
Edward
ed
Jess
Robinson
castaway
leklund
Martin
Bright
mlbright
Mike
Doherty
doherty
stro
Syohei
YOSHIDA
syohex
Tony
Cook
tony
lib
HTTP
Tiny
